import React from 'react';
import { Terminal } from 'lucide-react';
import TerminalButton from './components/TerminalButton';
import ProfileContent from './components/ProfileContent';
import ProjectsContent from './components/ProjectsContent';
import TerminalShell from './components/TerminalShell';
import SkillsContent from './components/SkillsContent';
import ResumeContent from './components/ResumeContent';
import PostsContent from './components/PostsContent';

function App() {
  const [activeSection, setActiveSection] = React.useState('about');

  return (
    <div className="min-h-screen bg-gray-900 flex items-center justify-center overflow-hidden">
      {/* TV Container with fixed proportions */}
      <div className="w-[95%] max-w-[1400px] relative h-[90vh]">
        {/* TV Frame */}
        <div className="absolute inset-0 tv-frame">
          {/* TV frame texture overlay */}
          <div className="tv-frame-texture"></div>
          
          {/* Edge shadow for added depth */}
          <div className="tv-frame-edge"></div>
          
          {/* Screen Container with fixed height and Convex Effect */}
          <div className="relative w-full h-full rounded-[20px] overflow-hidden tv-screen-container">
            {/* Convex Screen Effect */}
            <div className="absolute inset-0 tv-screen-convex"></div>
            
            {/* Static noise texture underlay */}
            <div className="white-noise"></div>

            {/* Screen Content with fixed height */}
            <div className="relative h-full w-full p-6 font-mono text-[#00FF00] overflow-hidden z-10 screen-content">
              <div className="animate-pulse mb-4">
                <Terminal className="inline-block mr-2" />
                <span className="text-sm">echo "Hey there!"</span>
              </div>

              {/* Split Screen Container with fixed height */}
              <div className="flex gap-8 h-[calc(100%-3rem)]">
                {/* Left Column - Navigation */}
                <div className="w-64 space-y-3 overflow-y-auto custom-scrollbar">
                  <TerminalButton
                    onClick={() => setActiveSection('about')}
                    isSelected={activeSection === 'about'}
                  >
                    ABOUT
                  </TerminalButton>
                  <TerminalButton
                    onClick={() => setActiveSection('projects')}
                    isSelected={activeSection === 'projects'}
                  >
                    PROJECTS
                  </TerminalButton>
                  <TerminalButton
                    onClick={() => setActiveSection('skills')}
                    isSelected={activeSection === 'skills'}
                  >
                    SKILLS
                  </TerminalButton>
                  <TerminalButton
                    onClick={() => setActiveSection('posts')}
                    isSelected={activeSection === 'posts'}
                  >
                    POSTS
                  </TerminalButton>
                  <TerminalButton
                    onClick={() => setActiveSection('resume')}
                    isSelected={activeSection === 'resume'}
                  >
                    RESUME
                  </TerminalButton>
                  <TerminalButton
                    onClick={() => setActiveSection('shell')}
                    isSelected={activeSection === 'shell'}
                  >
                    SHELL
                  </TerminalButton>
                </div>

                {/* Vertical Separator with embossed effect */}
                <div className="vertical-separator"></div>

                {/* Right Column - Content with scrolling */}
                <div className="flex-1 overflow-y-auto pr-4 custom-scrollbar">
                  {activeSection === 'about' && <ProfileContent />}
                  {activeSection === 'projects' && (
                    <ProjectsContent markdownPath="/content/projects.md" />
                  )}
                  {activeSection === 'skills' && <SkillsContent />}
                  {activeSection === 'posts' && <PostsContent />}
                  {activeSection === 'resume' && <ResumeContent />}
                  {activeSection === 'shell' && <TerminalShell />}
                </div>
              </div>
            </div>

            {/* Enhanced Scan Lines Effect */}
            <div className="scan-lines"></div>

            {/* Chromatic Aberration Effect */}
            <div className="chromatic-aberration"></div>

            {/* Multiple Glass Reflection Layers */}
            <div className="glass-reflection"></div>
            <div className="glass-reflection-2"></div>
            <div className="corner-shine"></div>

            {/* Screen Glare - Moving reflection */}
            <div className="screen-glare"></div>
          </div>
        </div>

        {/* TV Controls - Skeuomorphic Knobs */}
        <div className="absolute -bottom-12 right-20 flex space-x-8">
          <div className="tv-knob" style={{transform: 'rotate(-30deg)'}}></div>
          <div className="tv-knob" style={{transform: 'rotate(15deg)'}}></div>
          <div className="tv-knob" style={{transform: 'rotate(-10deg)'}}></div>
        </div>

        {/* TV Speaker Grills - Enhanced */}
        <div className="absolute -bottom-6 left-20 flex space-x-1.5">
          {[...Array(10)].map((_, i) => (
            <div 
              key={i} 
              className="w-1.5 h-6 bg-gradient-to-b from-gray-600 to-gray-800 rounded-full"
              style={{
                boxShadow: 'inset 0 1px 1px rgba(255,255,255,0.1), inset 0 -1px 1px rgba(0,0,0,0.3)'
              }}
            ></div>
          ))}
        </div>

        {/* TV Brand Label */}
        <div 
          className="absolute -bottom-10 left-1/2 transform -translate-x-1/2 bg-gradient-to-b from-gray-700 to-gray-900 px-4 py-1 rounded"
          style={{
            boxShadow: 'inset 0 1px 1px rgba(255,255,255,0.2), 0 1px 2px rgba(0,0,0,0.5)',
            border: '1px solid rgba(0,0,0,0.3)'
          }}
        >
          <span 
            className="text-xs text-gray-300 font-bold"
            style={{
              textShadow: '0 -1px 0 rgba(0,0,0,0.5)'
            }}
          >
            RETRO·VISION
          </span>
        </div>

        {/* Power indicator light */}
        <div className="absolute -bottom-8 right-[12%] w-3 h-3 rounded-full bg-gradient-to-b from-green-500 to-green-700" 
          style={{
            boxShadow: '0 0 5px #4AFF4A, inset 0 1px 2px rgba(255,255,255,0.4), inset 0 -1px 2px rgba(0,0,0,0.4)'
          }}>
          <div className="absolute inset-0 rounded-full bg-green-400 opacity-50 animate-pulse"></div>
        </div>
      </div>
    </div>
  );
}

export default App;